@@ -13,6 +13,9 @@ from .sum import Sum
 from .weekday import Weekday
 from .string_agg import StringAgg
 from .now import Now
+from .to_char import ToChar
+from .to_date import ToDate
+from .unaccent import Unaccent
 
 __all__ = [
     "Avg",
@@ -30,5 +33,8 @@ __all__ = [
     "Sum",
     "Weekday",
     "StringAgg",
-    "Now"
+    "Now",
+    "ToChar",
+    "ToDate",
+    "Unaccent"
 ]
